/*
Filename    : BTPairingDlg.cpp
Part of     : Phone Navigator
Description : Implementation of phone navigators bluetooth pairing dialog
Version     : 1.1

This example is only to be used with PC Suite Connectivity API version 1.1.
Compability ("as is") with future versions is not quaranteed.

Copyright (c) 2005 Nokia Corporation.
 
This material, including but not limited to documentation and any related 
computer programs, is protected by intellectual property rights of Nokia 
Corporation and/or its licensors.
All rights are reserved. Reproducing, modifying, translating, or 
distributing any or all of this material requires the prior written consent 
of Nokia Corporation. Nokia Corporation retains the right to make changes 
to this material at any time without notice. A copyright license is hereby 
granted to download and print a copy of this material for personal use only.
No other license to any other intellectual property rights is granted. The 
material is provided "as is" without warranty of any kind, either express or 
implied, including without limitation, any warranty of non-infringement, 
merchantability and fitness for a particular purpose. In no event shall 
Nokia Corporation be liable for any direct, indirect, special, incidental, 
or consequential loss or damages, including but not limited to, lost profits 
or revenue,loss of use, cost of substitute program, or loss of data or 
equipment arising out of the use or inability to use the material, even if 
Nokia Corporation has been advised of the likelihood of such damages occurring.
*/ 


#include "stdafx.h"
#include "PCCAPIUtils.h"
#include "phonenavigator.h"
#include "BTPairingDlg.h"
#include "ConnAPI.h"
#include "CONADeviceManagement.h"
#include "BTPasswordDlg.h"
#include "BTProgressDlg.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CBTPairingDlg dialog

BOOL g_bSearchCancelled = FALSE;
CBTProgressDlg g_ProgressDlg;

//===================================================================
// ProcessMessages
//
// Message loop. This is called frequently during the device search,
// to get window messages processed during this time consuming task.
//===================================================================
void ProcessMessages()
{
    MSG msg;
    while( ::PeekMessage( &msg, NULL, 0, 0, PM_REMOVE)){
        ::TranslateMessage( &msg);
        ::DispatchMessage( &msg);
    }
}

//===================================================================
// BTPairingNotifyCallback
//
// BT device searching callback function. If the progress dialog is
// visible, sets the progress dialog progress bar to the correct
// position.
// If global variable g_bSearchCancelled is set to TRUE, this
// function returns ECONA_CANCELLED, and connectivity API stops
// the device search.
// In other situations this function must always return CONA_OK.
//===================================================================
static DWORD CALLBACK BTPairingNotifyCallback( DWORD dwState, CONAPI_CONNECTION_INFO *pInfo)
{
    DWORD dwRet = CONA_OK;

    // check that progress dialog exists
    if( ::IsWindow( g_ProgressDlg.m_hWnd))
    {
        g_ProgressDlg.SetProgress( dwState);
    }

    if( g_bSearchCancelled){
        // If user has clicked Cancel, return ECONA_CANCELLED
        dwRet = ECONA_CANCELLED;
    }

    ProcessMessages();

    return dwRet;
}


//===================================================================
// CBTPairingDlg

//===================================================================
// Constructor
//
//===================================================================
CBTPairingDlg::CBTPairingDlg(CWnd* pParent /*=NULL*/)
	: CDialog(CBTPairingDlg::IDD, pParent)
{
	//{{AFX_DATA_INIT(CBTPairingDlg)
		// NOTE: the ClassWizard will add member initialization here
	//}}AFX_DATA_INIT
    m_hDM = NULL;

    DWORD dwRet = CONAOpenDM( &m_hDM);
    if( dwRet != CONA_OK){
        m_hDM = NULL;
        ErrorMessageDlg( L"CONAOpenDM failed.", dwRet);
    }
}

//===================================================================
// Destructor
//
//===================================================================
CBTPairingDlg::~CBTPairingDlg()
{
    DWORD dwRet = ECONA_UNKNOWN_ERROR;
    if( m_hDM){
        dwRet = CONACloseDM( m_hDM);
        if( dwRet != CONA_OK)
        {
            ErrorMessageDlg( L"CONACloseDM failed.", dwRet);
        }
    }
}

void CBTPairingDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CBTPairingDlg)
	DDX_Control(pDX, IDC_LIST_BT_PHONES, m_PhoneList);
	//}}AFX_DATA_MAP
}


BEGIN_MESSAGE_MAP(CBTPairingDlg, CDialog)
	//{{AFX_MSG_MAP(CBTPairingDlg)
	ON_BN_CLICKED(IDC_BUTTON_SEARCH, OnButtonSearch)
	ON_BN_CLICKED(IDC_BUTTON_PAIR, OnButtonPair)
	ON_BN_CLICKED(IDC_BUTTON_UNPAIR, OnButtonUnpair)
	ON_WM_DESTROY()
	ON_BN_CLICKED(IDC_BUTTON_SET_TRUSTED, OnButtonSetTrusted)
	ON_BN_CLICKED(IDC_BUTTON_SET_UNTRUSTED, OnButtonSetUntrusted)
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CBTPairingDlg message handlers

//===================================================================
// OnInitDialog
//
//===================================================================
BOOL CBTPairingDlg::OnInitDialog() 
{
    CRect rcList( 0,0,0,0);

	CDialog::OnInitDialog();

    m_PhoneList.GetClientRect( rcList);
    m_PhoneList.InsertColumn( 0, _T("Phone name"), LVCFMT_LEFT, rcList.Width()/2);
    m_PhoneList.InsertColumn( 1, _T("Status"), LVCFMT_LEFT, rcList.Width()/2);

    m_PhoneList.SetExtendedStyle( m_PhoneList.GetExtendedStyle() | LVS_EX_FULLROWSELECT);

    RefreshPhoneList( TRUE);

	return TRUE;  // return TRUE unless you set the focus to a control
	              // EXCEPTION: OCX Property Pages should return FALSE
}

//===================================================================
// ClearPhoneList
//
// Removes all items from the phone list, and frees memory
// allocated for each list item data
//===================================================================
void CBTPairingDlg::ClearPhoneList()
{
    int i = 0;
    int iCount = m_PhoneList.GetItemCount();
    CBTDevice *pDevice = NULL;

    for( i=0; i<iCount; i++){
        pDevice = (CBTDevice*)m_PhoneList.GetItemData( i);
        if( pDevice){
            delete pDevice;
            pDevice = NULL;
        }
    }

    m_PhoneList.DeleteAllItems();
}

//===================================================================
// GetSelectedDevice
//
// Returns pointer to the item data of the currently selected item
// in the phone list control, or NULL if no item is selected
//===================================================================
CBTDevice * CBTPairingDlg::GetSelectedDevice()
{
    int i = 0;
    int iCount = m_PhoneList.GetItemCount();
    CBTDevice *pDevice = NULL;

    for( i=0; i<iCount; i++){
        if( m_PhoneList.GetItemState( i, LVIS_SELECTED) & LVIS_SELECTED){
            pDevice = (CBTDevice*)m_PhoneList.GetItemData( i);
            break;
        }
    }

    return pDevice;
}

//===================================================================
// RefreshPhoneList
//
// Refreshes the phone list to the list control. If bSearchDevices
// is TRUE, searches all BT devices using connectivity API, else
// only copies the device information from memory to the list control.
//===================================================================
void CBTPairingDlg::RefreshPhoneList( BOOL bSearchDevices)
{
    const int iMaxSearchTime = 240;
        // This is the maximum time to be spent to the device search, in seconds.
        // The required time may vary a lot, make sure it is big enough. If this
        // timeout value is too small, CONASearchDevices returns ECONA_FAILED_TIMEOUT,
        // and PC Suite Connectivity API doesn't find all available devices.
    DWORD dwRet = ECONA_UNKNOWN_ERROR;
    DWORD dwDeviceCount = 0;
    DWORD dw = 0;
    CONAPI_CONNECTION_INFO *pInfo = NULL;
    CBTDevice *pDevice = NULL;

    if( m_hDM)
    {
        if( bSearchDevices)
        {
            // reset search cancel flag and show progress dialog.
            g_bSearchCancelled = FALSE;
            g_ProgressDlg.Create( IDD_SEARCH_PROGRESS_DIALOG, this);
            g_ProgressDlg.ShowWindow( SW_SHOW);
            ProcessMessages();

            dwRet = CONASearchDevices( m_hDM,
                CONAPI_MEDIA_BLUETOOTH | CONAPI_GET_ALL_PHONES,
                iMaxSearchTime,
                (PFN_CONA_SEARCH_CALLBACK)BTPairingNotifyCallback,
                &dwDeviceCount,
                &pInfo );

            ClearPhoneList();

            g_ProgressDlg.ShowWindow( SW_HIDE);
            g_ProgressDlg.DestroyWindow();

            if( dwRet != CONA_OK)
            {
                ErrorMessageDlg( L"CONASearchDevices failed.", dwRet);
            }

            if( pInfo){
                for( dw = 0; dw < dwDeviceCount; dw++)
                {
                    pDevice = new CBTDevice( pInfo[dw].pstrDeviceName,
                        pInfo[dw].pstrAddress,
                        pInfo[dw].dwDeviceID,
                        pInfo[dw].dwState );

                    m_PhoneList.InsertItem( dw, pInfo[dw].pstrDeviceName);
                    m_PhoneList.SetItemData( dw, (unsigned long)pDevice);
                }

                dwRet = CONAFreeConnectionInfoStructures( dwDeviceCount, &pInfo);
                if( dwRet != CONA_OK)
                {
                    ErrorMessageDlg( L"CONAFreeConnectionInfoStructures failed.", dwRet);
                }
            }

            if( dwRet == ECONA_CANCELLED)
            {
                m_PhoneList.InsertItem( dw++, L"Search cancelled");
            }
            else if( dwRet == ECONA_FAILED_TIMEOUT)
            {
                m_PhoneList.InsertItem( dw++, L"Timeout reached");
            }
            else if( dwRet != CONA_OK)
            {
                // other error happened
                m_PhoneList.InsertItem( dw++, L"Search failed");
            }
        }

        // update device status to the list
        dwDeviceCount = m_PhoneList.GetItemCount();
        for( dw=0; dw<dwDeviceCount; dw++){
            pDevice = (CBTDevice*)m_PhoneList.GetItemData( dw);
            if( pDevice){
                m_PhoneList.SetItemText( dw, 1, TrustedInfo2String( pDevice->GetStatus()));
            }
        }
    }
}

//===================================================================
// OnDestroy
//
//===================================================================
void CBTPairingDlg::OnDestroy() 
{
    ClearPhoneList();
	CDialog::OnDestroy();	
}

//===================================================================
// ChangeTrustedState
//
// Changes the device trusted state. dwTrustedState may be
// CONAPI_PAIR_DEVICE, CONAPI_UNPAIR_DEVICE, CONAPI_SET_PCSUITE_TRUSTED
// or CONAPI_SET_PCSUITE_UNTRUSTED. lpszPassword is needed only
// with CONAPI_PAIR_DEVICE, with other operations it must be NULL.
//===================================================================
DWORD CBTPairingDlg::ChangeTrustedState(DWORD dwTrustedState, LPCTSTR lpszPassword)
{
    DWORD dwRet = ECONA_UNKNOWN_ERROR;
    CBTDevice *pDevice = NULL;

    CWaitCursor wait;

    if( m_hDM){
        // get selected device from the list
        pDevice = GetSelectedDevice();

        if( pDevice){
            dwRet = CONAChangeDeviceTrustedState( m_hDM,
                dwTrustedState,
                pDevice->GetAddress(),
                lpszPassword,
                NULL);

            if( dwRet == CONA_OK){
                // change the device status to the list according to return value
                // re-searching all devices would take too long time
                if( dwTrustedState & CONAPI_PAIR_DEVICE){
                    pDevice->SetStatus( (pDevice->GetStatus() & CONAPI_DEVICE_PCSUITE_TRUSTED) | CONAPI_DEVICE_PAIRED);
                }
                else if( dwTrustedState & CONAPI_UNPAIR_DEVICE){
                    pDevice->SetStatus( (pDevice->GetStatus() & CONAPI_DEVICE_PCSUITE_TRUSTED) | CONAPI_DEVICE_UNPAIRED);
                }

                if( dwTrustedState & CONAPI_SET_PCSUITE_TRUSTED){
                    pDevice->SetStatus( pDevice->GetStatus() | CONAPI_DEVICE_PCSUITE_TRUSTED);
                }
                else if( dwTrustedState & CONAPI_SET_PCSUITE_UNTRUSTED){
                    pDevice->SetStatus( pDevice->GetStatus() & ~CONAPI_DEVICE_PCSUITE_TRUSTED);
                }

                RefreshPhoneList( FALSE);
            }
            else{
                ErrorMessageDlg( L"CONAChangeDeviceTrustedState failed.", dwRet);
            }
        }
        else{
            AfxMessageBox( L"Please select the phone from the list.");
        }
    }

    return dwRet;
}

//===================================================================
// OnButtonSearch
//
// Search button message handler
//===================================================================
void CBTPairingDlg::OnButtonSearch() 
{
    RefreshPhoneList( TRUE);
}

//===================================================================
// OnButtonPair
//
// Pairing button message handler
//===================================================================
void CBTPairingDlg::OnButtonPair() 
{
    CBTPasswordDlg dlg;

    dlg.SetPassword( L"123");
    if( dlg.DoModal() == IDOK)
    {
        ChangeTrustedState(	CONAPI_PAIR_DEVICE, dlg.GetPassword());
    }
}

//===================================================================
// OnButtonUnpair
//
// Unpair button message handler
//===================================================================
void CBTPairingDlg::OnButtonUnpair() 
{
    ChangeTrustedState(	CONAPI_UNPAIR_DEVICE, NULL);
}

//===================================================================
// OnButtonSetTrusted
//
// "Set device trusted" button message handler
//===================================================================
void CBTPairingDlg::OnButtonSetTrusted() 
{
    ChangeTrustedState(	CONAPI_SET_PCSUITE_TRUSTED, NULL);
}

//===================================================================
// OnButtonSetUntrusted
//
// "Set device untrusted" button message handler
//===================================================================
void CBTPairingDlg::OnButtonSetUntrusted() 
{
    ChangeTrustedState(	CONAPI_SET_PCSUITE_UNTRUSTED, NULL);
}
