/*
Filename    : FileOperationListener.cpp
Part of     : Phone Navigator
Description : Implementation of phone navigators file operation listener
Version     : 1.1

This example is only to be used with PC Suite Connectivity API version 1.1.
Compability ("as is") with future versions is not quaranteed.

Copyright (c) 2005 Nokia Corporation.
 
This material, including but not limited to documentation and any related 
computer programs, is protected by intellectual property rights of Nokia 
Corporation and/or its licensors.
All rights are reserved. Reproducing, modifying, translating, or 
distributing any or all of this material requires the prior written consent 
of Nokia Corporation. Nokia Corporation retains the right to make changes 
to this material at any time without notice. A copyright license is hereby 
granted to download and print a copy of this material for personal use only.
No other license to any other intellectual property rights is granted. The 
material is provided "as is" without warranty of any kind, either express or 
implied, including without limitation, any warranty of non-infringement, 
merchantability and fitness for a particular purpose. In no event shall 
Nokia Corporation be liable for any direct, indirect, special, incidental, 
or consequential loss or damages, including but not limited to, lost profits 
or revenue,loss of use, cost of substitute program, or loss of data or 
equipment arising out of the use or inability to use the material, even if 
Nokia Corporation has been advised of the likelihood of such damages occurring.
*/ 

#include "stdafx.h"
#include "PhoneNavigator.h"
#include "FileOperationListener.h"
#include "Resource.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

//===================================================================
// Construction/Destruction
//===================================================================

CFileOperationListener::CFileOperationListener()
{
    m_hFS = NULL;
//    m_pProgDlg = NULL;
}

CFileOperationListener::CFileOperationListener(HWND hwndParent, FSHANDLE hFS, CString title, CString line1, CString line2)
{
    TRACE(L"CFileOperationListener::CFileOperationListener(): Begin\n");
    m_hFS = hFS;
    TRACE(L"CFileOperationListener::CFileOperationListener(): StartListening...");
    DWORD dwResult = StartListening(m_hFS);
    if(dwResult == CONA_OK)
    {
        TRACE(L"succeeded\n");
    }
    else
    {
        ErrorMessageDlg(L"CFileOperationListener::CFileOperationListener(): StartListening failed!", dwResult);
        TRACE(L"failed\n");
    }
//    HRESULT hr = CoCreateInstance(CLSID_ProgressDialog, NULL, CLSCTX_INPROC_SERVER,   
//        IID_IProgressDialog, (void**)&m_pProgDlg);
//    if(FAILED(hr)) 
//    {
//        m_pProgDlg = NULL;
//    }
//    else
//    {   
//        m_pProgDlg->SetAnimation(AfxGetInstanceHandle(), IDR_FILE_COPY_AVI);
//        m_pProgDlg->SetTitle(title);
//        m_pProgDlg->SetLine(1, line1, FALSE, NULL);
//        m_pProgDlg->SetLine(2, line2, FALSE, NULL);
//        hr = m_pProgDlg->StartProgressDialog(hwndParent, NULL, PROGDLG_NORMAL | PROGDLG_NOMINIMIZE, NULL);
//        if(FAILED(hr))
//        {
//            TRACE(L"CFileOperationListener(): IProgressDialog::StartProgressDialog failed! (hr = 0x%x)\n", hr);
 //       }
 //   }
    TRACE(L"CFileOperationListener::CFileOperationListener(): End\n");
}

CFileOperationListener::~CFileOperationListener()
{
    TRACE(L"CFileOperationListener::~CFileOperationListener(): Begin\n");
    if(m_hFS)
    {
        TRACE(L"CFileOperationListener::~CFileOperationListener(): StopListening...");
        DWORD dwResult = StopListening(m_hFS);
        if(dwResult == CONA_OK)
        {
            TRACE(L"succeeded\n");
        }
        else
        {
            ErrorMessageDlg(L"CFileOperationListener::~CFileOperationListener(): StopListening failed!", dwResult);
            TRACE(L"failed\n");
        }
    }
//    if(m_pProgDlg != NULL)
//    {
//        m_pProgDlg->StopProgressDialog();
//        m_pProgDlg->Release();
//        m_pProgDlg = NULL;
//    }
    TRACE(L"CFileOperationListener::~CFileOperationListener(): End\n");
}

//===================================================================
// CCONAFSNotify methods
//===================================================================

DWORD CFileOperationListener::OperationState(DWORD dwFSFunction, DWORD dwState, DWORD dwTransferredBytes, DWORD dwAllBytes)
{
    DWORD reVal = CONA_OK;
    CString strState;
    switch(dwState)
    {
    case ECONA_CONNECTION_LOST: 
        strState = L"ECONA_CONNECTION_LOST";
        break;
    case ECONA_CONNECTION_REMOVED: 
        strState = L"ECONA_CONNECTION_REMOVED";
        break;
    case ECONA_CONNECTION_FAILED: 
        strState = L"ECONA_CONNECTION_FAILED";
        break;
    case ECONA_SUSPEND: 
        strState = L"ECONA_SUSPEND";
        break;
    default:
        strState.Format(L"%i %%", dwState);
    }
    TRACE(L"CFileOperationListener::OperationState():\n\tFunction = 0x%X(%s)\n\tState = %s\n\tTransferred = %i\n\tTotal = %i\n",
        dwFSFunction, DWORD2FSFunctionString(dwFSFunction), strState, dwTransferredBytes, dwAllBytes);
//    if(m_pProgDlg)
//    {
//        m_pProgDlg->SetProgress(dwTransferredBytes, dwAllBytes);
//        if(m_pProgDlg->HasUserCancelled())
//        {
//            reVal = ECONA_CANCELLED;
//        }
//    }
    return reVal;
}

DWORD CFileOperationListener::ConnectionLost(DWORD dwError)
{
    TRACE(L"CFileOperationListener::ConnectionLost(): Error = %i\n", dwError);    
    return CONA_OK;
}
