/*
==============================================================================
* PC Suite Connectivity API 1.1
*
Filename    : CONAApplicationInstallation.h
Description : Application Installation definitions and function
Version     : 1.1

Copyright (c) 2005 Nokia Corporation.
This software, including but not limited to documentation and any related 
computer programs ("Software"), is protected by intellectual property rights 
of Nokia Corporation and/or its licensors. All rights are reserved. By using 
the Software you agree to the terms and conditions hereunder. If you do not 
agree you must cease using the software immediately.
Reproducing, disclosing, modifying, translating, or distributing any or all 
of the Software requires the prior written consent of Nokia Corporation. 
Nokia Corporation retains the right to make changes to the Software at any 
time without notice.

A copyright license is hereby granted to use of the Software to make, publish, 
distribute, sub-license and/or sell new Software utilizing this Software. 
The Software may not constitute the primary value of any new software utilizing 
this software. No other license to any other intellectual property rights of 
Nokia or a third party is granted. 

THIS SOFTWARE IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESS 
OR IMPLIED, INCLUDING WITHOUT LIMITATION, ANY WARRANTY OF NON-INFRINGEMENT, 
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. IN NO EVENT SHALL
NOKIA CORPORATION BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL, 
OR CONSEQUENTIAL LOSS OR DAMAGES, INCLUDING BUT NOT LIMITED TO, LOST PROFITS 
OR REVENUE, LOSS OF USE, COST OF SUBSTITUTE PROGRAM, OR LOSS OF DATA OR EQUIPMENT 
ARISING OUT OF THE USE OR INABILITY TO USE THE MATERIAL, EVEN IF 
NOKIA CORPORATION HAS BEEN ADVISED OF THE LIKELIHOOD OF SUCH DAMAGES OCCURRING. 
==============================================================================
*/

#ifndef _CONAAPPLICATIONINSTALLATION_H_
#define _CONAAPPLICATIONINSTALLATION_H_

/////////////////////////////////////////////////////////////////////
// Connectivity API Application Installation definitions and function
/////////////////////////////////////////////////////////////////////

	//The next define values used to define which type of struct is used:
	#define CONA_APPLICATION_TYPE_SIS	0x00000001 // Use when struct type is CONAPI_APPLICATION_SIS
	#define CONA_APPLICATION_TYPE_JAVA	0x00000002 // Use when struct type is CONAPI_APPLICATION_JAVA

	//The struct for sis applications
	typedef struct
	{
		WCHAR*	pstrFileNameSis;	//sis application File name, must be set
						//The value can also include the file path in PC.
	} CONAPI_APPLICATION_SIS;

	//The struct for java applications
	typedef struct
	{
		WCHAR*	pstrFileNameJad;	//File name of the jad file. The value can also include the file path in PC. 
						//If jad file is not available, the value must be NULL.
		WCHAR*	pstrFileNameJar;	//File name of the jar file, must be set. 
						//The value can also include the file path in PC. 
	} CONAPI_APPLICATION_JAVA;

	//=========================================================
	// CONAInstallApplication 
	//
	// Description:
	//	CONAInstallApplication installs the given application on 
	//	the device. FS's CONACancel function can be used to cancel 
	//	this function. The application file name(s) must be given 
	//	in the CONAPI_APPLICATION_SIS or CONAPI_APPLICATION_JAVA 
	//	structure. 
	//	
	//	The function also checks the amount of free memory from 
	//	the phone before the installation. If there is not enough 
	//	memory left in the target memory drive, the function fails 
	//	with the error code ECONA_MEMORY_FULL.
	//	
	//	If the Application file type is sis, the CONAPI_APPLICATION_SIS 
	//	structure must be used. The dwAppicationType parameter's 
	//	value must be CONA_APPLICATION_TYPE_SIS.
	//	
	//	If the Application file type is jar, the CONAPI_APPLICATION_JAVA 
	//	structure must be used. The dwAppicationType parameter's 
	//	value must be CONA_APPLICATION_TYPE_JAVA.
	//
	// Parameters:
	//	hFSHandle			[in] File System handle
	//	dwApplicationType	[in] Used struct type: CONA_APPLICATION_TYPE_SIS or 
	//						   CONA_APPLICATION_TYPE_JAVA
	//	pApplicationStruct	[in] Pointer to CONAPI_APPLICATION_SIS or 
	//							 CONAPI_APPLICATION_JAVA struct.
	//	dwOptions			[in] Options: 
	//		CONA_DEFAULT_FOLDER: Copies the application to the device's default 
	//		application folder automatically and starts the device's installer 
	//		(if required to do so).Target path or current folder is not used.  
	//		CONA_OVERWRITE:	Overwrites the application file if it already 
	//		exists in the target folder.
	//
	//	pstrSourcePath		[in] Source folder path on the PC. The value must be NULL, 
	//					 if path is given with file name(s) in Application structure.
	//	pstrTargetPath   	[in] Target folder.If NULL, current folder is used.
	//					 If CONA_DEFAULT_FOLDER is used,Application will 
	//					 be installed to device's default application folder. 
	//
	// Return values:
	// CONA_OK
	// ECONA_INVALID_HANDLE
	// ECONA_INVALID_PARAMETER
	// ECONA_CONNECTION_BUSY
	// ECONA_CONNECTION_LOST
	// ECONA_INVALID_DATA_DEVICE
	// ECONA_MEMORY_FULL
	// ECONA_CURRENT_FOLDER_NOT_FOUND
	// ECONA_FOLDER_PATH_TOO_LONG
	// ECONA_FOLDER_NOT_FOUND
	// ECONA_FOLDER_NO_PERMISSION_ON_PC
	// ECONA_FILE_TOO_BIG_DEVICE
	// ECONA_FILE_NAME_INVALID
	// ECONA_FILE_NAME_TOO_LONG
	// ECONA_FILE_TYPE_NOT_SUPPORTED
	// ECONA_FILE_NOT_FOUND
	// ECONA_FILE_ALREADY_EXIST
	// ECONA_FILE_NO_PERMISSION
	// ECONA_FILE_NO_PERMISSION_ON_PC
	// ECONA_FILE_BUSY
	// ECONA_DEVICE_INSTALLER_BUSY
	// ECONA_CANCELLED
	// ECONA_FAILED_TIMEOUT
	// ECONA_FILE_TYPE_NOT_SUPPORTED
	// ECONA_NOT_SUPPORTED_DEVICE
	// ECONA_UNKNOWN_ERROR_DEVICE
	// ECONA_NOT_INITIALIZED
	// ECONA_NOT_SUPPORTED_MANUFACTURER
	// ECONA_UNKNOWN_ERROR

	CONN_API CONAInstallApplication( FSHANDLE hFSHandle,
									 DWORD	dwApplicationType,
									 LPVOID  pApplicationStruct,
									 DWORD	dwOptions,
									 const WCHAR* pstrSourcePath,
									 const WCHAR* pstrTargetPath);

	//=========================================================

#endif
