/*
==============================================================================
* PC Suite Connectivity API 1.1
*
Filename    : CONADefinitions.h
Description : General API definitions 
Version     : 1.1

Copyright (c) 2005 Nokia Corporation.
This software, including but not limited to documentation and any related 
computer programs ("Software"), is protected by intellectual property rights 
of Nokia Corporation and/or its licensors. All rights are reserved. By using 
the Software you agree to the terms and conditions hereunder. If you do not 
agree you must cease using the software immediately.
Reproducing, disclosing, modifying, translating, or distributing any or all 
of the Software requires the prior written consent of Nokia Corporation. 
Nokia Corporation retains the right to make changes to the Software at any 
time without notice.

A copyright license is hereby granted to use of the Software to make, publish, 
distribute, sub-license and/or sell new Software utilizing this Software. 
The Software may not constitute the primary value of any new software utilizing 
this software. No other license to any other intellectual property rights of 
Nokia or a third party is granted. 

THIS SOFTWARE IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESS 
OR IMPLIED, INCLUDING WITHOUT LIMITATION, ANY WARRANTY OF NON-INFRINGEMENT, 
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. IN NO EVENT SHALL
NOKIA CORPORATION BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL, 
OR CONSEQUENTIAL LOSS OR DAMAGES, INCLUDING BUT NOT LIMITED TO, LOST PROFITS 
OR REVENUE, LOSS OF USE, COST OF SUBSTITUTE PROGRAM, OR LOSS OF DATA OR EQUIPMENT 
ARISING OUT OF THE USE OR INABILITY TO USE THE MATERIAL, EVEN IF 
NOKIA CORPORATION HAS BEEN ADVISED OF THE LIKELIHOOD OF SUCH DAMAGES OCCURRING. 
==============================================================================
*/


#ifndef _CONADEFINITIONS_H__
#define _CONADEFINITIONS_H__

//=========================================================
// Common data type definitions used in Connectivity API
//
	#include "CONATypeDefinitions.h"
//=========================================================

#ifndef CONN_API
	#define CONN_API EXTERN_C __declspec(dllimport) DWORD STDAPICALLTYPE
#endif
#ifndef CONN_APIEX
	#define CONN_APIEX(type) EXTERN_C __declspec(dllimport) type STDAPICALLTYPE
#endif
#ifndef CONN_API_CLASS
	#define CONN_API_CLASS __declspec(dllimport)
#endif


//=========================================================
// Common definitions used in Connectivity API
//
	// Values used in callback registering methods
	#define	CONAPI_REGISTER		0x00
	#define	CONAPI_UNREGISTER	0x01

//=========================================================
// Device definitions used in Connectivity API

	// ----------------------------------------------------
	// Connectivity API device management handle
	typedef LPVOID	DMHANDLE;
	// ----------------------------------------------------

	// ----------------------------------------------------
	// Media types
	#define	CONAPI_MEDIA_ALL		0x01
	#define	CONAPI_MEDIA_IRDA		0x02
	#define	CONAPI_MEDIA_SERIAL		0x04
	#define	CONAPI_MEDIA_BLUETOOTH	0x08
	#define	CONAPI_MEDIA_USB		0x10
	// ----------------------------------------------------

	// ----------------------------------------------------
	// Connection info structure
	typedef struct
	{
		DWORD		dwDeviceID;
		DWORD		dwMedia;
		WCHAR*		pstrDeviceName;
		WCHAR*		pstrAddress;
		DWORD		dwState;
	} CONAPI_CONNECTION_INFO;

	// Device info structure
	typedef struct
	{
		WCHAR*		pstrSerialNumber;
		WCHAR*		pstrFriendlyName;
		WCHAR*		pstrModel;
		WCHAR*		pstrManufacturer;
		DWORD		dwNumberOfItems;
		CONAPI_CONNECTION_INFO* pItems;
	} CONAPI_DEVICE;
	// ----------------------------------------------------


	// Search definitions used with CONASearchDevices function:
	#define	CONAPI_DEVICE_UNPAIRED				0x00000001	// Device is not paired
	#define	CONAPI_DEVICE_PAIRED				0x00000002	// Device is paired
	#define	CONAPI_DEVICE_PCSUITE_TRUSTED		0x00000004	// Device is PC Suite trusted

	#define	CONAPI_ALLOW_TO_USE_CACHE			0x00001000	// Get all devices from cache if available
	#define	CONAPI_GET_ALL_PHONES				0x00002000	// Get all phones from target media
	#define	CONAPI_GET_PAIRED_PHONES			0x00004000	// Get all paired phones from target media
	#define	CONAPI_GET_TRUSTED_PHONES			0x00008000	// Get all PC Suite trusted phones from target media.

	// Search macros used to check device's trusted/paired state: 
	#define	CONAPI_IS_DEVICE_UNPAIRED(dwState)	(dwState & 0x01)		// Returns 1 if true
	#define	CONAPI_IS_DEVICE_PAIRED(dwState)	((dwState >> 1) & 0x01) // Returns 1 if true
	#define	CONAPI_IS_PCSUITE_TRUSTED(dwState)	((dwState >> 2) & 0x01) // Returns 1 if true
 
	// Definitions used with CONAChangeDeviceTrustedState function:
	#define	CONAPI_PAIR_DEVICE					0x00000100	// Pair device
	#define	CONAPI_UNPAIR_DEVICE				0x00000200	// Unpair device
	#define	CONAPI_SET_PCSUITE_TRUSTED			0x00000400	// Set device to PC Suite trusted 
	#define	CONAPI_SET_PCSUITE_UNTRUSTED		0x00000800	// Remove PC Suite trusted information.
	// ----------------------------------------------------
	// DeviceNotifyCallbackFunction
	//
	//	This is the function prototype of the callback method
	//
	//	DWORD DeviceNotifyCallbackFunction(	DWORD dwStatus, WCHAR* pstrSerialNumber);
	//	
	//	Status value uses the following format:
	//
	//		----------------DWORD------------------
	//		WORD for info		WORD for status
	//		0000 0000 0000 0000 0000 0000 0000 0000
	//
	//	Status value is the one of the values defined below describing main reason for the notification.
	//	Info part consist of two parts:
	//		LOBYTE: Info part contains change info value. See info values below.
	//		HIBYTE:	Info data value. Depends of info value.
	//	See info value definitions for more information.
	//	Use predefined macros to extract needed part from the status value.
	//
	typedef DWORD (CALLBACK *PFN_CONA_DEVICE_CALLBACK)(	DWORD dwStatus, WCHAR* pstrSerialNumber);

	// Device callback status values
	#define	CONAPI_DEVICE_LIST_UPDATED	0x00	// List is updated. No any specific information.
	#define	CONAPI_DEVICE_ADDED			0x01	// A new device is added to the list.
	#define	CONAPI_DEVICE_REMOVED		0x02	// Device is removed from the list.
	#define	CONAPI_DEVICE_UPDATED		0x04	// Device is updated. A connection is added or removed
												// or device is renamed. Device still exist in the list.
	// Device callback info values
	#define	CONAPI_CONNECTION_ADDED		0x01	// Note! HIBYTE == media, LOBYTE == CONAPI_CONNECTION_ADDED
	#define	CONAPI_CONNECTION_REMOVED	0x02	// Note! HIBYTE == media, LOBYTE == CONAPI_CONNECTION_REMOVED
	#define	CONAPI_DEVICE_RENAMED		0x04	// Friendly name of the device is changed

	// Device callback macros
	#define	GET_CONAPI_CB_STATUS(Status)	(0x0000FFFF & Status)
	#define	GET_CONAPI_CB_INFO(Status)		((0x00FF0000 & Status)>>16)
	#define	GET_CONAPI_CB_INFO_DATA(Status)	((0xFF000000 & Status)>>24)
	// ----------------------------------------------------

	// ----------------------------------------------------
	// CCONADeviceNotify
	//
		#ifdef __cplusplus
			class CONN_API_CLASS CCONADeviceNotify
			{
			public:
				DWORD StartListening();
				DWORD StopListening();
			public:
				virtual void DeviceListUpdated(){};
				virtual void DeviceAdded(WCHAR* pstrSN, DWORD dwStatus){};
				virtual void DeviceRemoved(WCHAR* pstrSN, DWORD dwStatus){};
				virtual void DeviceUpdated(WCHAR* pstrSN, DWORD dwStatus){};
			};
		#endif
	// ----------------------------------------------------

	// ----------------------------------------------------------------------
	// DeviceSearchOperationCallbackFunction
	//
	// Description
	// Device Search operation callback functions are defined as: 
	//	DWORD (DeviceSearchOperationCallbackFunction)(DWORD dwState, 
	//					CONAPI_CONNECTION_INFO* pConnInfoStructure)
	//
	//	The Connectivity API calls this function periodically (or if the
	//	System has found the device during this time) and adds one 
	//	to the function state value. The used time period is counted by using 
	//	dwSearchTime parameter. E.g. If dwSearchTime paramater value is 240,
	//	time period  (240/100) is 2.4 seconds.
	//	If the function state is 100 and any device have not been found during 
	//	this (dwSearchTime) time the CONASearchDevices function fails with the 
	//	error code ECONA_FAILED_TIMEOUT.
	//
	// Parameters
	//	dwState				[in] Function state (0-100%).
	//	pConnInfoStructure	[in] Reserved for future use, the value is NULL.
	//
	// Return values
	// The Connectivity API-user must return the CONA_OK value. If the callback 
	// function returns the error code ECONA_CANCELLED to the Connectivity API, 
	// the CONASearchDevices function will be cancelled with the error code ECONA_CANCELLED.
	//
	// Type definition: 
	typedef DWORD (CALLBACK *PFN_CONA_SEARCH_CALLBACK)(	DWORD dwState, 
										CONAPI_CONNECTION_INFO* pConnInfoStructure);
	// -----------------------------------------------------------------------

	

//=========================================================

//=========================================================
// File System definitions used in Connectivity API	

	typedef LPVOID	FSHANDLE;				// Connectivity API file system handle
	typedef LPVOID	FINDHANDLE;				// Connectivity API find handle

	//Used for changing current folder:
	#define GO_TO_ROOT_FOLDER				L"\\\\"        
	#define GO_TO_PARENT_FOLDER				L"..\\"
	#define FOLDER_SEPARATOR				L"\\"

	//Options for CONADeleteFolder:
	#define CONA_DELETE_FOLDER_EMPTY		0x00000000	
	#define CONA_DELETE_FOLDER_WITH_FILES	0x00000001

	//Direction options for CONACopyFile and CONAMoveFile:
	#define CONA_DIRECT_PHONE_TO_PC			0x00000002
	#define CONA_DIRECT_PC_TO_PHONE			0x00000004
	#define CONA_DIRECT_PHONE_TO_PHONE		0x00000008	// Not used at the moment.

	//Other options for CONACopyFile and CONAMoveFile:
	#define CONA_OVERWRITE					0x00000010	
	#define CONA_RENAME						0x00000020	// Used only with CONACopyFile
	#define CONA_TRANSFER_ALL				0x00000040	// Not used at the moment.

	//Options for CONAFindBegin:
	#define CONA_FIND_USE_CACHE				0x00000080

	//Attribute defines for CONAPI_FOLDER_INFO and CONAPI_FILE_INFO structures:
	#define CONA_FPERM_READ					0x00000100	// Both structure
	#define CONA_FPERM_WRITE				0x00000200	// Both structure
	#define CONA_FPERM_DELETE				0x00000400	// Both structure
	#define CONA_FPERM_FOLDER				0x00000800	// Only for CONAPI_FOLDER_INFO
	#define CONA_FPERM_DRIVE				0x00001000	// Only for CONAPI_FOLDER_INFO


	#define CONA_DEFAULT_FOLDER				0x00010000  //Used only with CONAInstallApplication
	// ----------------------------------------------------
	// Folder info structure
	typedef struct 
	{
		WCHAR*		pstrName;		// Folder or Drive name
		DWORD		dwAttributes;	// Folder or Drive type and permission 
		FILETIME	tFolderTime;	// Folder time
		WCHAR*		pstrLabel;		// Drive lable name 
		WCHAR*		pstrMemoryType;	// Folder or Drive memory type
	} CONAPI_FOLDER_INFO;

	// File info structure
	typedef struct 
	{
		WCHAR*		pstrName;		// File name
		DWORD		dwAttributes;	// File permission
		FILETIME	tFileTime;		// File modified time
		DWORD		dwFileSize;		// File size
		WCHAR*		pstrMIMEType;	// File MIME type
	} CONAPI_FILE_INFO;

	typedef CONAPI_FOLDER_INFO* LPCONAPI_FOLDER_INFO;
	typedef CONAPI_FILE_INFO*   LPCONAPI_FILE_INFO;
	// ----------------------------------------------------

	// ----------------------------------------------------
	// FileOperationCallbackFunction function:

	// ----------------------------------------------------
	//	This is the function prototype of the callback method
	//
	//	DWORD FileOperationCallbackFunction(
	//							   DWORD dwFSFunction, 
	//							   DWORD dwState,
	//							   DWORD dwTransferredBytes,
	//							   DWORD dwAllBytes);
	//
	typedef DWORD (CALLBACK *PFN_CONA_FS_CALLBACK)(
								DWORD dwFSFunction,
								DWORD dwState,
								DWORD dwTransferredBytes,
								DWORD dwAllBytes );

	// ----------------------------------------------------
	// CCONAFSNotify
	//
		#ifdef __cplusplus
			class CONN_API_CLASS CCONAFSNotify
			{
			public:
				DWORD StartListening(FSHANDLE hFSHandle);
				DWORD StopListening(FSHANDLE hFSHandle);
			public:
				virtual DWORD OperationState(DWORD dwFSFunction,
											DWORD dwState,
											DWORD dwTransferredBytes,
											DWORD dwAllBytes ){ return CONA_OK; };
				virtual DWORD ConnectionLost(DWORD dwError){ return CONA_OK; }
			};
		#endif
	// ----------------------------------------------------

	// FSFunction values:
	#define CONARefreshDeviceMemoryValuesNtf	0x00000001
	#define CONASetCurrentFolderNtf				0x00000002
	#define CONAFindBeginNtf					0x00000004
	#define CONACreateFolderNtf					0x00000008
	#define CONADeleteFolderNtf					0x00000010
	#define CONARenameFolderNtf					0x00000020
	#define CONAGetFileInfoNtf					0x00000040
	#define CONADeleteFileNtf					0x00000080
	#define CONAMoveFileNtf						0x00000100
	#define CONACopyFileNtf						0x00000200
	#define CONARenameFileNtf					0x00000400
	#define CONAReadFileNtf						0x00000800
	#define CONAWriteFileNtf					0x00001000
	#define CONAConnectionLostNtf 				0x00002000
	#define CONAInstallApplicationNtf			0x00004000
	#define CONAConvertFileNtf					0x00008000
	// The next function do not send notifications:
	//	CONAOpenFS					
	//	CONACloseFS				
	//	CONARegisterFSNotifyCallback
	//	CONAGetMemoryTypes 			
	//	CONAGetMemoryValues			
	//	CONAGetCurrentFolder	
	//	CONAFindNextFolder		
	//	CONAFindNextFile		
	//	CONAFindEnd					
	//	CONACancel				

	// Possible error codes value in dwStatus parameter when 
	// FSFunction value is CONAConnectionLost:
	//	ECONA_CONNECTION_LOST
	//  ECONA_CONNECTION_REMOVED
	//  ECONA_CONNECTION_FAILED
	//  ECONA_SUSPEND
	// ----------------------------------------------------

//=========================================================

#endif
