/*
Filename    : PhoneNavigatorDlg.cpp
Part of     : Phone Navigator
Description : Implementation of phone navigators dialog class
Version     : 1.1

This example is only to be used with PC Suite Connectivity API version 1.1.
Compability ("as is") with future versions is not quaranteed.

Copyright (c) 2005 Nokia Corporation.
 
This material, including but not limited to documentation and any related 
computer programs, is protected by intellectual property rights of Nokia 
Corporation and/or its licensors.
All rights are reserved. Reproducing, modifying, translating, or 
distributing any or all of this material requires the prior written consent 
of Nokia Corporation. Nokia Corporation retains the right to make changes 
to this material at any time without notice. A copyright license is hereby 
granted to download and print a copy of this material for personal use only.
No other license to any other intellectual property rights is granted. The 
material is provided "as is" without warranty of any kind, either express or 
implied, including without limitation, any warranty of non-infringement, 
merchantability and fitness for a particular purpose. In no event shall 
Nokia Corporation be liable for any direct, indirect, special, incidental, 
or consequential loss or damages, including but not limited to, lost profits 
or revenue,loss of use, cost of substitute program, or loss of data or 
equipment arising out of the use or inability to use the material, even if 
Nokia Corporation has been advised of the likelihood of such damages occurring.
*/ 

#include "stdafx.h"
#include "PhoneNavigator.h"
#include "PhoneNavigatorDlg.h"
#include "RenameDlg.h"
#include "CreateDlg.h"
#include "FileOperationListener.h"
#include "BTPairingDlg.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

//===================================================================
// CPhoneNavigatorDlg dialog

//===================================================================
// Constructor
//
//===================================================================
CPhoneNavigatorDlg::CPhoneNavigatorDlg(CWnd* pParent /*=NULL*/)
	: CDialog(CPhoneNavigatorDlg::IDD, pParent)
{
	//{{AFX_DATA_INIT(CPhoneNavigatorDlg)
		// NOTE: the ClassWizard will add member initialization here
	//}}AFX_DATA_INIT
	// Note that LoadIcon does not require a subsequent DestroyIcon in Win32
	m_hIcon = AfxGetApp()->LoadIcon(IDR_MAINFRAME);
}

//===================================================================
// Destructor
//
//===================================================================
CPhoneNavigatorDlg::~CPhoneNavigatorDlg()
{   
}

void CPhoneNavigatorDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CPhoneNavigatorDlg)
	DDX_Control(pDX, IDC_STATIC_PHONE, m_staticPhone);
	DDX_Control(pDX, IDC_STATIC_PCFILES, m_staticPCFiles);
	DDX_Control(pDX, IDC_LIST_PHONES, m_lbPhones);
	DDX_Control(pDX, IDC_PCFILES, m_lbPCFiles);
	//}}AFX_DATA_MAP
}

BEGIN_MESSAGE_MAP(CPhoneNavigatorDlg, CDialog)
	//{{AFX_MSG_MAP(CPhoneNavigatorDlg)    
	ON_BN_CLICKED(IDC_BUTTON_COPYPC2PHONE, OnButtonCopypc2phone)
	ON_BN_CLICKED(IDC_BUTTON_MOVEPHONE2PC, OnButtonMovephone2pc)	
    ON_BN_CLICKED(IDC_BUTTON_COPYPHONE2PC, OnButtonCopyphone2pc)
	ON_BN_CLICKED(IDC_BUTTON_CREATE, OnButtonCreate)
	ON_BN_CLICKED(IDC_BUTTON_RENAME, OnButtonRename)
	ON_BN_CLICKED(IDC_BUTTON_DELETE, OnButtonDelete)
    ON_BN_CLICKED(IDC_BUTTON_MOVEPC2PHONE, OnButtonMovepc2phone)
	ON_WM_SYSCOMMAND()	
	ON_BN_CLICKED(IDC_BUTTON_BT_PAIRING, OnButtonBtPairing)
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

//===================================================================
// RefreshPhoneList
//
// Lists all connected phones to listbox
//===================================================================
void CPhoneNavigatorDlg::RefreshPhoneList()
{    
    m_lbPhones.ListAllPhones();
}

//===================================================================
// CPhoneNavigatorDlg message handlers

BOOL CPhoneNavigatorDlg::OnInitDialog()
{
	CDialog::OnInitDialog();

	// Set the icon for this dialog.  The framework does this automatically
	//  when the application's main window is not a dialog
	SetIcon(m_hIcon, TRUE);			// Set big icon
	SetIcon(m_hIcon, FALSE);		// Set small icon
	
    // Initializing PC file list:
    m_lbPCFiles.Init(&m_staticPCFiles);

    // Initializing phone file list:
    m_lbPhones.Init(&m_staticPhone);

    RefreshPhoneList();

	return TRUE;  // return TRUE  unless you set the focus to a control
}

//===================================================================
// OnButtonMovepc2phone
//
// Moves selected pc file to selected phone folder
//===================================================================
void CPhoneNavigatorDlg::OnButtonMovepc2phone() 
{
    TRACE(L"CPhoneNavigatorDlg::OnButtonMovepc2phone(): Begin\n");
    if(m_lbPCFiles.GetCurrentFile().IsEmpty())
    { // no PC file selected
        AfxMessageBox(L"Please select PC file to be moved.");
    }
    else
    {
        FSHANDLE hFS = NULL;
        DWORD dwMedia = CONAPI_MEDIA_ALL;
        DWORD dwDeviceID = 0;        
        DWORD dwResult = CONAOpenFS(m_lbPhones.GetCurrentSN(), &dwMedia, &hFS, &dwDeviceID);
        if(dwResult == CONA_OK)
        {            
            CString strPCFile = m_lbPCFiles.GetCurrentFile(); // file name without path
            CString strPCFolder = m_lbPCFiles.GetCurrentFolder(); // e.g. 'c:\temp\'
            CString strPhoneFolder = m_lbPhones.GetSelectedFolder(); 
            if(strPhoneFolder.IsEmpty())
            {
                strPhoneFolder = m_lbPhones.GetCurrentFolder();
            }
            CFileOperationListener* pListener = new CFileOperationListener(m_hWnd, 
                hFS, 
                L"Moving", 
                strPCFolder + L"\\" + strPCFile, 
                L"-->" + strPhoneFolder);
            dwResult = CONAMoveFile(hFS, 
                CONA_DIRECT_PC_TO_PHONE, 
                strPCFile, 
                strPCFolder,  
                strPhoneFolder);
            delete pListener;
            pListener = NULL;
            if(dwResult != CONA_OK)
            {
                ErrorMessageDlg(L"CPhoneNavigatorDlg::OnButtonMovepc2phone(): CONAMoveFile failed!", dwResult);                
            }
            else
            {
                // show updated folder listings
                m_lbPCFiles.ShowFiles();
                m_lbPhones.ShowPhoneFolder(strPhoneFolder);
                AfxMessageBox(L"Move completed succesfully!");
            }
            dwResult = CONACloseFS(hFS);
            if(dwResult != CONA_OK)
            {
                ErrorMessageDlg(L"CPhoneNavigatorDlg::OnButtonMovepc2phone(): CONACloseFS failed!", dwResult);                
            }
        }
        else
        {
            ErrorMessageDlg(L"CPhoneNavigatorDlg::OnButtonMovepc2phone(): CONAOpenFS failed!", dwResult);
        }
    }        
    TRACE(L"CPhoneNavigatorDlg::OnButtonMovepc2phone(): End\n");
}


//===================================================================
// OnButtonCopypc2phone
//
// Copies selected pc file to selected phone folder
//===================================================================
void CPhoneNavigatorDlg::OnButtonCopypc2phone() 
{
    TRACE(L"CPhoneNavigatorDlg::OnButtonCopypc2phone(): Begin\n");
    if(m_lbPCFiles.GetCurrentFile().IsEmpty())
    {
        AfxMessageBox(L"Please select PC file to be copied.");
    }
    else
    {
        FSHANDLE hFS = NULL;
        DWORD dwMedia = CONAPI_MEDIA_ALL;
        DWORD dwDeviceID = 0;
        DWORD dwResult = CONAOpenFS(m_lbPhones.GetCurrentSN(), &dwMedia, &hFS, &dwDeviceID);
        if(dwResult == CONA_OK)
        {            
            CString strPCFile = m_lbPCFiles.GetCurrentFile(); // file name without path
            CString strPCFolder = m_lbPCFiles.GetCurrentFolder(); // e.g. 'c:\temp'
            CString strPhoneFolder = m_lbPhones.GetSelectedFolder(); 
            if(strPhoneFolder.IsEmpty())
            {
                strPhoneFolder = m_lbPhones.GetCurrentFolder();
            }
            CFileOperationListener* pListener = new CFileOperationListener(m_hWnd, 
                hFS, 
                L"Copying", 
                strPCFolder + L"\\" + strPCFile, 
                L"-->" + strPhoneFolder);
            dwResult = CONACopyFile(hFS, 
                CONA_DIRECT_PC_TO_PHONE | CONA_RENAME, 
                strPCFile, 
                strPCFolder,  
                strPhoneFolder);
            delete pListener;
            pListener = NULL;
            if(dwResult != CONA_OK)
            {
                ErrorMessageDlg(L"CPhoneNavigatorDlg::OnButtonCopypc2phone(): CONACopyFile failed!", dwResult);                
            }
            else
            {
                // show updated folder listing
                m_lbPhones.ShowPhoneFolder(strPhoneFolder);
                AfxMessageBox(L"Copy completed succesfully!");
            }
            dwResult = CONACloseFS(hFS);
            if(dwResult != CONA_OK)
            {
                ErrorMessageDlg(L"CPhoneNavigatorDlg::OnButtonCopypc2phone(): CONACloseFS failed!", dwResult);                
            }
        }
        else
        {
            ErrorMessageDlg(L"CPhoneNavigatorDlg::OnButtonCopypc2phone(): CONAOpenFS failed!", dwResult);
        }
    }
    TRACE(L"CPhoneNavigatorDlg::OnButtonCopypc2phone(): End\n");
}

//===================================================================
// OnButtonMovephone2pc
//
// Moves selected phone file to selected pc folder
//===================================================================
void CPhoneNavigatorDlg::OnButtonMovephone2pc() 
{
    TRACE(L"CPhoneNavigatorDlg::OnButtonMovephone2pc(): Begin\n");	
    CString strMessage = L"";
    CString file = m_lbPhones.GetCurrentFile();
    if(file.IsEmpty())
    {
        AfxMessageBox(L"Please select phone file to be moved.");
    }
    else
    {
        FSHANDLE hFS = NULL;
        DWORD dwMedia = CONAPI_MEDIA_ALL;
        DWORD dwDeviceID = 0;
        DWORD dwResult = CONAOpenFS(m_lbPhones.GetCurrentSN(), &dwMedia, &hFS, &dwDeviceID);
        if(dwResult == CONA_OK)
        {
            CString strPhoneFile = m_lbPhones.GetCurrentFile();            
            CString strPhoneFolder = m_lbPhones.GetSelectedFolder();
            CString strPCFolder = m_lbPCFiles.GetCurrentFolder();
            strMessage.Format(L"Are you sure you want to move phone file '%s' from folder '%s' to\nPC folder '%s'?", 
                strPhoneFile, strPhoneFolder, strPCFolder);
            if(AfxMessageBox(strMessage, MB_YESNO) == IDYES)
            {
                CFileOperationListener* pListener = new CFileOperationListener(m_hWnd, 
                    hFS, 
                    L"Moving", 
                    strPhoneFolder + L"\\" + strPhoneFile, 
                    L"-->" + strPCFolder);
                dwResult = CONAMoveFile(hFS, 
                    CONA_DIRECT_PHONE_TO_PC,
                    strPhoneFile, 
                    strPhoneFolder,
                    strPCFolder);
                delete pListener;
                pListener = NULL;
                if(dwResult != CONA_OK)
                {
                    ErrorMessageDlg(L"CPhoneNavigatorDlg::OnButtonMovephone2pc(): CONAMoveFile failed!", dwResult);                
                }
                else
                {
                    // show updated folder listings
                    m_lbPhones.ShowPhoneFolder(strPhoneFolder);
                    m_lbPCFiles.ShowFiles();
                    AfxMessageBox(L"Move completed succesfully!");
                }
            }
            dwResult = CONACloseFS(hFS);
            if(dwResult != CONA_OK)
            {
                ErrorMessageDlg(L"CPhoneNavigatorDlg::OnButtonMovephone2pc(): CONACloseFS failed!", dwResult);                
            }
        }
        else
        {
            ErrorMessageDlg(L"CPhoneNavigatorDlg::OnButtonMovephone2pc(): CONAOpenFS failed!", dwResult);
        }
    }    
    TRACE(L"CPhoneNavigatorDlg::OnButtonMovephone2pc(): End\n");
}

//===================================================================
// OnButtonCopyphone2pc
//
// Copies selected phone file to selected pc folder
//===================================================================
void CPhoneNavigatorDlg::OnButtonCopyphone2pc() 
{
    TRACE(L"CPhoneNavigatorDlg::OnButtonCopyphone2pc(): Begin\n");
    CString file = m_lbPhones.GetCurrentFile();
    if(file.IsEmpty())
    {
        AfxMessageBox(L"Please select phone file to be copied.");
    }
    else
    {
        FSHANDLE hFS = NULL;
        DWORD dwMedia = CONAPI_MEDIA_ALL;
        DWORD dwDeviceID = 0;
        DWORD dwResult = CONAOpenFS(m_lbPhones.GetCurrentSN(), &dwMedia, &hFS, &dwDeviceID);
        if(dwResult == CONA_OK)
        {
            CString strPhoneFile = m_lbPhones.GetCurrentFile();                        
            CString strPCFolder = m_lbPCFiles.GetCurrentFolder();
            CString strPhoneFolder = m_lbPhones.GetSelectedFolder(); 
            CFileOperationListener* pListener = new CFileOperationListener(m_hWnd, 
                hFS, 
                L"Copying", 
                strPhoneFolder + L"\\" + strPhoneFile, 
                L"-->" + strPCFolder);
            dwResult = CONACopyFile(hFS, 
                CONA_DIRECT_PHONE_TO_PC | CONA_RENAME, 
                strPhoneFile, 
                strPhoneFolder,
                strPCFolder);
            delete pListener;
            pListener = NULL;
            if(dwResult != CONA_OK)
            {
                ErrorMessageDlg(L"CPhoneNavigatorDlg::OnButtonCopyphone2pc(): CONACopyFile failed!", dwResult);                
            }
            else
            {
                // show updated folder listing
                m_lbPCFiles.ShowFiles();
                AfxMessageBox(L"Copy completed succesfully!");
            }
            dwResult = CONACloseFS(hFS);
            if(dwResult != CONA_OK)
            {
                ErrorMessageDlg(L"CPhoneNavigatorDlg::OnButtonCopyphone2pc(): CONACloseFS failed!", dwResult);                
            }
        }
        else
        {
            ErrorMessageDlg(L"CPhoneNavigatorDlg::OnButtonCopyphone2pc(): CONAOpenFS failed!", dwResult);
        }
    }    
    TRACE(L"CPhoneNavigatorDlg::OnButtonCopyphone2pc(): End\n");
}

//===================================================================
// OnButtonCreate
//
// Creates new folder to selected phone folder
//===================================================================
void CPhoneNavigatorDlg::OnButtonCreate() 
{
    TRACE(L"CPhoneNavigatorDlg::OnButtonCreate(): Begin\n");
    CCreateDlg dlg;
    dlg.m_strName = L"";
    if(dlg.DoModal() == IDOK)
    {
        FSHANDLE hFS = NULL;
        DWORD dwMedia = CONAPI_MEDIA_ALL;
        DWORD dwDeviceID = 0;
        DWORD dwResult = CONAOpenFS(m_lbPhones.GetCurrentSN(), &dwMedia, &hFS, &dwDeviceID);
        if(dwResult == CONA_OK)
        {
            CString strPhoneFolder = m_lbPhones.GetCurrentFolder();
            CFileOperationListener* pListener = new CFileOperationListener(m_hWnd, 
                hFS, 
                L"Creating", 
                strPhoneFolder + L"\\" + dlg.m_strName, 
                L"");
            dwResult = CONACreateFolder(hFS, dlg.m_strName, strPhoneFolder);
            delete pListener;
            pListener = NULL;
            if(dwResult != CONA_OK)
            {
                ErrorMessageDlg(L"CPhoneNavigatorDlg::OnButtonCreate(): CONACreateFolder failed!", dwResult);                
            }
            else
            {
                // show updated folder listing
                m_lbPhones.ShowPhoneFolder(strPhoneFolder);
                AfxMessageBox(L"Create folder completed succesfully!");
            }
            dwResult = CONACloseFS(hFS);
            if(dwResult != CONA_OK)
            {
                ErrorMessageDlg(L"CPhoneNavigatorDlg::OnButtonCreate(): CONACloseFS failed!", dwResult);                
            }
        }
        else
        {
            ErrorMessageDlg(L"CPhoneNavigatorDlg::OnButtonCreate(): CONAOpenFS failed!", dwResult);
        }
    }
    TRACE(L"CPhoneNavigatorDlg::OnButtonCreate(): End\n");
}

//===================================================================
// OnButtonRename
//
// Renames selected phone file/folder
//===================================================================
void CPhoneNavigatorDlg::OnButtonRename() 
{  
    TRACE(L"CPhoneNavigatorDlg::OnButtonRename(): Begin\n");
    BOOL bIsFile = TRUE; // selected item is file - not folder
    if(m_lbPhones.GetCurSel() != LB_ERR)
    {
        CRenameDlg dlg;
        dlg.m_strOldName = m_lbPhones.GetCurrentFile();
        if(dlg.m_strOldName.IsEmpty())
        {
            bIsFile = FALSE; // selected item is folder - not file
            dlg.m_strOldName = m_lbPhones.GetSelectedFolder();
        }
        if(!dlg.m_strOldName.IsEmpty())
        {
            if(dlg.DoModal() == IDOK)
            {
                FSHANDLE hFS = NULL;
                DWORD dwMedia = CONAPI_MEDIA_ALL;
                DWORD dwDeviceID = 0;
                DWORD dwResult = CONAOpenFS(m_lbPhones.GetCurrentSN(), &dwMedia, &hFS, &dwDeviceID);
                if(dwResult == CONA_OK)
                {           
                    if(dwResult == CONA_OK)
                    {
                        CString strPhoneFolder = m_lbPhones.GetCurrentFolder();
                        CString strNewName = dlg.m_strNewName;
                        CString strOldName = dlg.m_strOldName;
                        strOldName = strOldName.Mid(strOldName.ReverseFind('\\') + 1);
                        if(bIsFile)
                        {
                            dwResult = CONARenameFile(hFS, strOldName, strNewName, strPhoneFolder);
                        }
                        else
                        {
                            dwResult = CONARenameFolder(hFS, strOldName, strNewName, strPhoneFolder);
                        }
                        if(dwResult == CONA_OK)
                        {
                            // show updated folder listing
                            m_lbPhones.ShowPhoneFolder(strPhoneFolder);
                            AfxMessageBox(L"Rename completed succesfully!");
                        }
                        else
                        {
                            if(bIsFile)
                                ErrorMessageDlg(L"CPhoneNavigatorDlg::OnButtonRename(): CONARenameFile failed!", dwResult);
                            else
                                ErrorMessageDlg(L"CPhoneNavigatorDlg::OnButtonRename(): CONARenameFolder failed!", dwResult);
                        }
                    }
                    else
                    {
                        ErrorMessageDlg(L"CPhoneNavigatorDlg::OnButtonRename(): CONAGetCurrentFolder failed!", dwResult);
                    }
                }
                dwResult = CONACloseFS(hFS);
                if(dwResult != CONA_OK)
                {
                    ErrorMessageDlg(L"CPhoneNavigatorDlg::OnButtonRename(): CONACloseFS failed!", dwResult);                
                }
            }
        }
        else
        {
            CONAPI_DEVICE* pDevice = (CONAPI_DEVICE*)m_lbPhones.GetItemDataPtr(m_lbPhones.GetCurSel());
            dlg.m_strOldName = pDevice->pstrFriendlyName;
            if(!dlg.m_strOldName.IsEmpty())
            {
                if(dlg.DoModal() == IDOK)
                {
                    WCHAR szNewName[MAX_PATH] = {0};
                    wcsncpy(szNewName, dlg.m_strNewName, MAX_PATH);
                    TRACE(L"CPhoneNavigatorDlg::OnButtonRename(): %s --> %s, Calling RenameFriendlyName(%s, %s)...\n", dlg.m_strOldName, szNewName, pDevice->pstrSerialNumber, szNewName);
                    DWORD dwResult = CONARenameFriendlyName(m_lbPhones.GetDMHandle(), pDevice->pstrSerialNumber, szNewName);
                    if(dwResult != CONA_OK)
                    {
                        ErrorMessageDlg(L"CPhoneNavigatorDlg::OnButtonRename(): RenameFriendlyName failed!", dwResult);                
                    }
                    else
                    {
                        m_lbPhones.ListAllPhones();
                    }
                }
            }
        }
    }
    else
    {
        AfxMessageBox(L"Please select file/folder to be renamed.");
    }
    TRACE(L"CPhoneNavigatorDlg::OnButtonRename(): End\n");
}

//===================================================================
// OnButtonDelete
//
// Deletes selected phone file/folder
//===================================================================
void CPhoneNavigatorDlg::OnButtonDelete()
{
    TRACE(L"CPhoneNavigatorDlg::OnButtonDelete(): Begin\n");
    if(m_lbPhones.GetState() == PHONELIST_STATE_PHONECONTENT)
    {
        CString strMessage;
        FSHANDLE hFS = NULL;
        DWORD dwMedia = CONAPI_MEDIA_ALL;
        DWORD dwDeviceID = 0;    
        DWORD dwResult = CONAOpenFS(m_lbPhones.GetCurrentSN(), &dwMedia, &hFS, &dwDeviceID);
        if(dwResult == CONA_OK)
        {
            CString strSelectedtxt = L"";
            int cursel = m_lbPhones.GetCurSel();
            if(cursel != LB_ERR)
            {
                m_lbPhones.GetText(cursel, strSelectedtxt);
            }
	        CString strSelectedFile = m_lbPhones.GetCurrentFile();
            if(!strSelectedFile.IsEmpty())
            {            
                CString strPhoneFile = m_lbPhones.GetCurrentFile();            
                CString strPhoneFolder = m_lbPhones.GetSelectedFolder();            
                strMessage.Format(L"Are you sure you want to permanently delete file '%s' from folder '%s'?", strPhoneFile, strPhoneFolder);
                if(AfxMessageBox(strMessage, MB_YESNO) == IDYES)
                {
                    CFileOperationListener* pListener = new CFileOperationListener(m_hWnd,                     
                        hFS, 
                        L"Deleting", 
                        strPhoneFolder + L"\\" + strPhoneFile, 
                        L"");
                    dwResult = CONADeleteFile(hFS,                 
                        strPhoneFile, 
                        strPhoneFolder);
                    delete pListener;
                    pListener = NULL;
                    if(dwResult != CONA_OK)
                    {
                        ErrorMessageDlg(L"CPhoneNavigatorDlg::OnButtonDelete(): CONADeleteFile failed!", dwResult);                
                    }
                    else
                    {
                        // show updated folder listing
                        m_lbPhones.ShowPhoneFolder(strPhoneFolder);
                        AfxMessageBox(L"Delete file completed succesfully!");
                    }
                }
            }
            else if(!strSelectedtxt.IsEmpty() && strSelectedtxt != L"[..]")
            {                 
                WCHAR strPhoneFolder[MAX_PATH] = {0};
                wcsncpy(strPhoneFolder, m_lbPhones.GetSelectedFolder(), MAX_PATH);
                ::PathRemoveFileSpec(strPhoneFolder);
                CString strFolder = *((CString*)m_lbPhones.GetItemDataPtr(m_lbPhones.GetCurSel()));
                strMessage.Format(L"Are you sure you want to permanently delete folder '%s' from folder '%s'?", strFolder, strPhoneFolder);
                if(AfxMessageBox(strMessage, MB_YESNO) == IDYES)
                {
                    CFileOperationListener* pListener = new CFileOperationListener(m_hWnd,                     
                        hFS, 
                        L"Deleting", 
                        CString(strPhoneFolder) + L"\\" + strFolder, 
                        L"");
                    dwResult = CONADeleteFolder(hFS, strFolder, CONA_DELETE_FOLDER_WITH_FILES, strPhoneFolder);
                    delete pListener;
                    pListener = NULL;
                    if(dwResult != CONA_OK)
                    {
                        ErrorMessageDlg(L"CPhoneNavigatorDlg::OnButtonDelete(): CONADeleteFolder failed!", dwResult);
                    }
                    else
                    {
                        // show updated folder listing
                        m_lbPhones.ShowPhoneFolder(strPhoneFolder);
                        AfxMessageBox(L"Delete folder completed succesfully!");
                    }
                }
            }
            else
            {
                AfxMessageBox(L"Select file/folder to be deleted.");
            }
            dwResult = CONACloseFS(hFS);
            if(dwResult != CONA_OK)
            {
                ErrorMessageDlg(L"CPhoneNavigatorDlg::OnButtonDelete(): CONACloseFS failed!", dwResult);                
            }
        }	  
        else
        {
            ErrorMessageDlg(L"CPhoneNavigatorDlg::OnButtonDelete(): CONAOpenFS failed!", dwResult);
        }
    }
    else
    { // state is phonelist
        AfxMessageBox(L"Please select phone file/folder to be deleted.");
    }
    TRACE(L"CPhoneNavigatorDlg::OnButtonDelete(): End\n");
}

void CPhoneNavigatorDlg::OnOK() 
{
	// Disabled to prevent closing dialog by pressing enter
}

void CPhoneNavigatorDlg::OnCancel() 
{
	CDialog::OnCancel();
}

void CPhoneNavigatorDlg::OnButtonBtPairing() 
{
    CBTPairingDlg dlg;
    dlg.DoModal();
}
